==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/GroupRuleAction.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.GroupRuleGroupAssignment;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Defines which users and groups to assign
 */
@ApiModel(description = "Defines which users and groups to assign")
@JsonPropertyOrder({ GroupRuleAction.JSON_PROPERTY_ASSIGN_USER_TO_GROUPS })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class GroupRuleAction implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ASSIGN_USER_TO_GROUPS = "assignUserToGroups";
    private GroupRuleGroupAssignment assignUserToGroups;

    public GroupRuleAction() {
    }

    public GroupRuleAction assignUserToGroups(GroupRuleGroupAssignment assignUserToGroups) {

        this.assignUserToGroups = assignUserToGroups;
        return this;
    }

    /**
     * Get assignUserToGroups
     *
     * @return assignUserToGroups
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ASSIGN_USER_TO_GROUPS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public GroupRuleGroupAssignment getAssignUserToGroups() {
        return assignUserToGroups;
    }

    @JsonProperty(JSON_PROPERTY_ASSIGN_USER_TO_GROUPS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAssignUserToGroups(GroupRuleGroupAssignment assignUserToGroups) {
        this.assignUserToGroups = assignUserToGroups;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        GroupRuleAction groupRuleAction = (GroupRuleAction) o;
        return Objects.equals(this.assignUserToGroups, groupRuleAction.assignUserToGroups);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(assignUserToGroups);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class GroupRuleAction {\n");
        sb.append("    assignUserToGroups: ").append(toIndentedString(assignUserToGroups)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/GroupRuleAction.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.GroupRuleGroupAssignment;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Defines which users and groups to assign
 */
@ApiModel(description = "Defines which users and groups to assign")
@JsonPropertyOrder({ GroupRuleAction.JSON_PROPERTY_ASSIGN_USER_TO_GROUPS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class GroupRuleAction implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ASSIGN_USER_TO_GROUPS = "assignUserToGroups";
    private GroupRuleGroupAssignment assignUserToGroups;

    public GroupRuleAction() {
    }

    public GroupRuleAction assignUserToGroups(GroupRuleGroupAssignment assignUserToGroups) {

        this.assignUserToGroups = assignUserToGroups;
        return this;
    }

    /**
     * Get assignUserToGroups
     *
     * @return assignUserToGroups
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ASSIGN_USER_TO_GROUPS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public GroupRuleGroupAssignment getAssignUserToGroups() {
        return assignUserToGroups;
    }

    @JsonProperty(JSON_PROPERTY_ASSIGN_USER_TO_GROUPS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAssignUserToGroups(GroupRuleGroupAssignment assignUserToGroups) {
        this.assignUserToGroups = assignUserToGroups;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        GroupRuleAction groupRuleAction = (GroupRuleAction) o;
        return Objects.equals(this.assignUserToGroups, groupRuleAction.assignUserToGroups);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(assignUserToGroups);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class GroupRuleAction {\n");
        sb.append("    assignUserToGroups: ").append(toIndentedString(assignUserToGroups)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
